@@ -53,13 +53,18 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
         return self.db_remove('Logical_Switch', switch_uuid, 'dns_records',
                               dns_uuid, if_exists=if_exists)
 
+    def ls_get_localnet_ports(self, switch, if_exists=False):
+        return cmd.LSGetLocalnetPortsCommand(self, switch, if_exists)
+
     def acl_add(self, switch, direction, priority, match, action, log=False,
                 may_exist=False, **external_ids):
         return cmd.AclAddCommand(self, switch, direction, priority,
                                  match, action, log, may_exist, **external_ids)
 
-    def acl_del(self, switch, direction=None, priority=None, match=None):
-        return cmd.AclDelCommand(self, switch, direction, priority, match)
+    def acl_del(self, switch, direction=None, priority=None, match=None,
+                if_exists=False):
+        return cmd.AclDelCommand(self, switch, direction, priority, match,
+                                 if_exists)
 
     def acl_list(self, switch):
         return cmd.AclListCommand(self, switch)
@@ -73,9 +78,9 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
                                    **external_ids)
 
     def pg_acl_del(self, port_group, direction=None, priority=None,
-                   match=None):
+                   match=None, if_exists=False):
         return cmd.PgAclDelCommand(self, port_group, direction, priority,
-                                   match)
+                                   match, if_exists)
 
     def pg_acl_list(self, port_group):
         return cmd.PgAclListCommand(self, port_group)
@@ -209,8 +214,8 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
     def lrp_get_enabled(self, port):
         return cmd.LrpGetEnabledCommand(self, port)
 
-    def lrp_set_options(self, port, **options):
-        return cmd.LrpSetOptionsCommand(self, port, **options)
+    def lrp_set_options(self, port, if_exists=False, **options):
+        return cmd.LrpSetOptionsCommand(self, port, if_exists, **options)
 
     def lrp_get_options(self, port):
         return cmd.LrpGetOptionsCommand(self, port)
@@ -233,15 +238,18 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
         return cmd.LrpDelNetworksCommand(self, port, networks, if_exists)
 
     def lr_route_add(self, router, prefix, nexthop, port=None,
-                     policy='dst-ip', may_exist=False):
+                     policy='dst-ip', may_exist=False, ecmp=False,
+                     route_table=const.MAIN_ROUTE_TABLE, bfd=None):
         return cmd.LrRouteAddCommand(self, router, prefix, nexthop, port,
-                                     policy, may_exist)
+                                     policy, may_exist, ecmp, route_table, bfd)
 
-    def lr_route_del(self, router, prefix=None, if_exists=False):
-        return cmd.LrRouteDelCommand(self, router, prefix, if_exists)
+    def lr_route_del(self, router, prefix=None, if_exists=False, nexthop=None,
+                     route_table=const.MAIN_ROUTE_TABLE):
+        return cmd.LrRouteDelCommand(self, router, prefix, if_exists, nexthop,
+                                     route_table)
 
-    def lr_route_list(self, router):
-        return cmd.LrRouteListCommand(self, router)
+    def lr_route_list(self, router, route_table=None):
+        return cmd.LrRouteListCommand(self, router, route_table)
 
     def lr_nat_add(self, router, nat_type, external_ip, logical_ip,
                    logical_port=None, external_mac=None, may_exist=False):
@@ -289,7 +297,7 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
         return cmd.LbDelHealthCheckCommand(self, lb, hc_uuid, if_exists)
 
     def lb_add_ip_port_mapping(self, lb, endport_ip, port_name, source_ip):
-        return cmd.LbAddIpPortMappingСommand(self, lb, endport_ip,
+        return cmd.LbAddIpPortMappingCommand(self, lb, endport_ip,
                                              port_name, source_ip)
 
     def lb_del_ip_port_mapping(self, lb, endport_ip):
@@ -364,6 +372,10 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
     def dns_set_external_ids(self, uuid, **external_ids):
         return cmd.DnsSetExternalIdsCommand(self, uuid, **external_ids)
 
+    def dns_set_options(self, uuid, if_exists=True, **options):
+        return cmd.DnsSetOptionsCommand(self, uuid, if_exists=if_exists,
+                                        **options)
+
     def pg_add(self, name=None, may_exist=False, **columns):
         return cmd.PgAddCommand(self, name, may_exist=may_exist, **columns)
 
@@ -412,3 +424,42 @@ class OvnNbApiIdlImpl(ovs_idl.Backend, api.API):
 
     def meter_get(self, meter):
         return cmd.MeterGetCommand(self, meter)
+
+    def bfd_add(self, logical_port, dst_ip, min_tx=None, min_rx=None,
+                detect_mult=None, external_ids=None, options=None,
+                may_exist=False):
+        return cmd.BFDAddCommand(self, logical_port, dst_ip, min_tx=min_tx,
+                                 min_rx=min_rx, detect_mult=detect_mult,
+                                 external_ids=external_ids, options=options,
+                                 may_exist=may_exist)
+
+    def bfd_del(self, uuid):
+        return cmd.BFDDelCommand(self, uuid)
+
+    def bfd_find(self, logical_port, dst_ip):
+        return cmd.BFDFindCommand(self, logical_port, dst_ip)
+
+    def bfd_get(self, uuid):
+        return cmd.BFDGetCommand(self, uuid)
+
+    def mirror_get(self, uuid):
+        return cmd.MirrorGetCommand(self, uuid)
+
+    def mirror_del(self, mirror):
+        return cmd.MirrorDelCommand(self, mirror)
+
+    def mirror_add(self, name, mirror_type, index, direction_filter,
+                   dest, external_ids=None, may_exist=False):
+        return cmd.MirrorAddCommand(self, name=name,
+                                    mirror_type=mirror_type,
+                                    index=index,
+                                    direction_filter=direction_filter,
+                                    dest=dest,
+                                    external_ids=external_ids,
+                                    may_exist=may_exist)
+
+    def lsp_attach_mirror(self, port, mirror, may_exist=False):
+        return cmd.LspAttachMirror(self, port, mirror, may_exist)
+
+    def lsp_detach_mirror(self, port, mirror, if_exist=False):
+        return cmd.LspDetachMirror(self, port, mirror, if_exist)
